/* This file has been generated by the CMake lxqt_app_translation_loader().
 * It loads LXQt application translations.
 *
 * Attention: All changes will be overwritten!!!
 */

#include <QCoreApplication>
#include <LXQt/Translator>

static void loadAppTranslation()
{
    LXQt::Translator::translateApplication(QStringLiteral("lxqt-about"));
}

Q_COREAPP_STARTUP_FUNCTION(loadAppTranslation)
